@@ -53,5 +53,5 @@ if __name__ == "__main__":
             "Operating System :: OS Independent",
         ),
         python_requires=">=3.6",
-        entry_points={"console_scripts": ("package = package.__main__:main",)},
+        entry_points={"console_scripts": ("tool = tool.__main__:main",)},
     )
